Functional Regression with scalar response using selection of number of penalized principal componentes PPC(or partial least squares components PPLS) through cross-validation. The algorithm selects the PPLS components with best estimates the response. The selection is performed by cross-validation (CV) or Model Selection Criteria (MSC). After is computing functional regression using the best selection of PPC (or PPLS) components.
fregre.ppc.cv(fdataobj, y, kmax=8, lambda = 0, P = c(0, 0, 1),
criteria = "SIC", ...) fregre.ppls.cv(fdataobj, y, kmax=8, lambda = 0, P = c(0, 0, 1),
criteria = "SIC", ...)
fdata class object.
Scalar response with length n.
The number of components to include in the model.
Vector with the amounts of penalization. Default value is 0, i.e. no penalization is used.
If lambda=TRUE the algorithm computes a sequence of lambda values.
If P is a vector: P are coefficients to define the penalty matrix object. By default P=c(0,0,1) penalize the second derivative (curvature) or acceleration.
If P is a matrix: P is the penalty matrix object.
Type of cross-validation (CV) or Model Selection Criteria (MSC) applied. Possible values are "CV", "AIC", "AICc", "SIC".
Further arguments passed to fregre.ppc or fregre.ppls
Return:
Index of PC or PLS components selected.
Minimum Model Selection Criteria (MSC) value for the (pc.opt or pls.opt) components.
Minimum Model Selection Criteria (MSC) value for kmax components.
Fitted regression object by the best (pc.opt or pls.opt) components.
The algorithm is as follows:
Select the bests components (pc.opt or pls.opt) with minimum MSC criteria by stepwise regression using fregre.ppc or fregre.ppls in each step.
Fit the functional PPLS regression between \(\tilde{X}(t)\) and \(Y\) using the best selection of FPLS components pls.opt.
For more details in estimation process see fregre.ppc or fregre.ppls.
The criteria selection is done by cross-validation (CV) or Model Selection Criteria (MSC).
Predictive Cross-Validation: \(PCV(k_n)=\frac{1}{n}\sum_{i=1}^{n}{\Big(y_i -\hat{y}_{(-i,k_n)} \Big)^2}\),
criteria=``CV''
Model Selection Criteria: \(MSC(k_n)=log \left[ \frac{1}{n}\sum_{i=1}^{n}{\Big(y_i-\hat{y}_i\Big)^2} \right] +p_n\frac{k_n}{n} \)
\(p_n=\frac{log(n)}{n}\), criteria=``SIC'', Schwarz information criterion (by default).
\(p_n=\frac{log(n)}{n-k_n-2}\), criteria=``SICc'', corrected Schwarz information criterion.
\(p_n=2\), criteria=``AIC'', Akaike information criterion.
\(p_n=\frac{2n}{n-k_n-2}\), criteria=``AICc'', corrected Akaike information criterion
\(p_n=\frac{2log(log(n))}{n}\), criteria=``HQIC'', Hannan-Quinn information criterion.
The generalized minimum description length (gmdl) criteria:
\(gmdl(k_n)=log \left[ \frac{1}{n-k_n}\sum_{i=1}^{n}{\Big(y_i-\hat{y}_i\Big)^2} \right] +K_n log \left(\frac{(n-k_n)\sum_{i=1}^{n}\hat{y}_i^2}{{\sum_{i=1}^{n}\Big(y_i-\hat{y}_i\Big)^2} }\right)+log(n) \)
where criteria is an argument that controls the type of validation used in the selection of the smoothing parameter kmax\(=k_n\) and penalized parameter lambda\(=\lambda\).
criteria=``CV'' is not recommended: time-consuming.
Schwarz, G. (1978). Estimating the dimension of a model. The annals of statistics, 6(2), 461-464.
Hannan, E. J., Quinn, B. G. (1979). The determination of the order of an autoregression. Journal of the Royal Statistical Society. Series B (Methodological), 190-195.
Preda C. and Saporta G. PLS regression on a stochastic process. Comput. Statist. Data Anal. 48 (2005): 149-158.
Kraemer, N., Sugiyama M. (2011). The Degrees of Freedom of Partial Least Squares Regression. Journal of the American Statistical Association. Volume 106, 697-705.
Febrero-Bande, M., Oviedo de la Fuente, M. (2012). Statistical Computing in Functional Data Analysis: The R Package fda.usc. Journal of Statistical Software, 51(4), 1-28. http://www.jstatsoft.org/v51/i04/
See also as: fregre.ppls and fregre.ppc .